/* 
 * (c) 2015 - 2020 Juan Balderas
 * This file is part of Dibuja.

 * Dibuja is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * Dibuja is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Dibuja.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _UNDO_H_
#define _UNDO_H_

#include <gtk/gtk.h>
#include "simple-canvas.h"
#include "undo-linear.h"

#define UNDO_DEF_MAX	(20)

typedef enum{
	UNDO_TYPE_BRUSH = 0,
	UNDO_TYPE_CURVE,
	UNDO_TYPE_FLOOD_FILL,
	UNDO_TYPE_LINE,
	UNDO_TYPE_PENCIL,
	UNDO_TYPE_POLYLINE,
	UNDO_TYPE_SELECT,
	UNDO_TYPE_SHAPE,
	UNDO_TYPE_TEXT,
	UNDO_TYPE_FLIP_HORZ,
	UNDO_TYPE_FLIP_VERT,
	UNDO_TYPE_ROTATE,
	UNDO_TYPE_RESIZE,
	UNDO_TYPE_SCALE,
	UNDO_TYPE_INVERT,
	UNDO_TYPE_GRAYSCALE,
	UNDO_TYPE_INSTA_BRANNAN,
	UNDO_TYPE_INSTA_1977,
	UNDO_TYPE_EMBOSS,
	UNDO_TYPE_CLEAR,
	UNDO_TYPE_CROP,
	UNDO_TYPE_BRIGHTNESS_CONTRAST,
	UNDO_TYPE_GAUSSIAN_BLUR,
	UNDO_TYPE_THRESHOLD,
	UNDO_TYPE_POSTERIZE,
	UNDO_TYPE_VIGNETTE,
	UNDO_TYPE_SHARPEN,
	UNDO_TYPE_FLIP,
	UNDO_TYPE_LAST
}UndoType;

int undo_init(SimpleCanvas *canvas);
void undo_add(SimpleCanvas *canvas, GdkRectangle rect, gchar *desc,
			  UndoType type);
void undo_do_undo(SimpleCanvas *canvas);
void undo_do_redo(SimpleCanvas *canvas);
void undo_add_from_surface(SimpleCanvas *canvas, cairo_surface_t *surface,
						   GdkRectangle rect, gchar *desc, UndoType type);
gboolean undo_can_undo(SimpleCanvas *canvas);
gboolean undo_can_redo(SimpleCanvas *canvas);
void undo_clear(SimpleCanvas *canvas);
//void undo_update_menu_text(SimpleCanvas *canvas);
void undo_add_temp(SimpleCanvas *canvas, gchar *desc, UndoType type);

#endif
