/*
 * Copyright © 2009-2015 Siyan Panayotov <contact@siyanpanayotov.com>
 *
 * Based on code by (see README for details):
 * - Björn Lindqvist <bjourne@gmail.com>
 *
 * This file is part of Viewnior.
 *
 * Viewnior is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Viewnior is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Viewnior.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __UNI_EXIV2__H_
#define __UNI_EXIV2__H_ 

#ifdef __cplusplus

#include <exiv2/exiv2.hpp>

extern "C" {
#include <glib/gi18n.h>

    typedef Exiv2::ExifData::const_iterator (*ExifDataFinder)(const Exiv2::ExifData& ed);
    typedef struct _ExifDataDictionary ExifDataDictionary;
    typedef struct _IptcDataDictionary IptcDataDictionary;

    struct _ExifDataDictionary {
        const char *key;
        const char *label;
        ExifDataFinder finder;
    };

    struct _IptcDataDictionary {
        const char *key;
        const char *label;
    };

    ExifDataDictionary exifDataDictionary[] = {
        { "Exif.Image.UniqueCameraModel", N_("Camera make"), Exiv2::make },
        { "Exif.Image.LocalizedCameraModel", N_("Camera model"), Exiv2::model },
        { "Exif.Photo.DateTimeOriginal", N_("Date Taken"), NULL },
        { "Exif.Photo.ExposureTime", N_("Exposure time"), Exiv2::exposureTime },
        { "Exif.Photo.ExposureMode", N_("Exposure mode"), Exiv2::exposureMode },
        { "Exif.Photo.ApertureValue", N_("Aperture Value"), NULL },
        { "Exif.Photo.ISOSpeedRatings", N_("ISO speed"), Exiv2::isoSpeed },
        { "Exif.Photo.Flash", N_("Flash"), NULL },
        { "Exif.Photo.MeteringMode", N_("Metering mode"), Exiv2::meteringMode },
        { "Exif.Image.FocalLength", N_("Focal length"), Exiv2::focalLength },
        { "Exif.Image.Software", N_("Software"), NULL }
    };

    IptcDataDictionary iptcDataDictionary[] = {
        { "Iptc.Application2.Caption", N_("Description") },
        { "Iptc.Application2.Copyright", N_("Copyright") },
        { "Iptc.Application2.Byline", N_("Author") }
    };


#endif /* __cplusplus */

typedef void (*Exif2Callback)(const char* lab, const char* val, void* userdata);

#if 0
void    uni_exif_dictionary_map     (Exif2Callback callback, void *user_data);
#endif
void    uni_read_exiv2_map          (const char *uri, Exif2Callback callback, 
                                     void *user_data);

int     uni_read_exiv2_to_cache     (const char *uri);
int     uni_write_exiv2_from_cache  (const char *uri);

#ifdef __cplusplus

} /* end extern "C" */

#endif /* __cplusplus */


#endif /* __UNI_EXIV2__H_ */
